@@ -1,57 +1,40 @@
 package POD2::ES;
-
-use 5.005;
+use warnings;
 use strict;
-use vars qw($VERSION);
-$VERSION = '5.12.3.01_1';
-
-use base qw(Exporter);
-our @EXPORT = qw(print_pod print_pods search_perlfunc_re new pod_dirs);
 
 use utf8;
+use base 'POD2::Base';
+
+our $VERSION = '5.12.3.01_2';
 
 my $pods = {
-    perlintro	=> '5.12.3',
-    # perl	=> '5.12.3',
-    # perlbook	=> '5.12.3',
-    # perlcheat => '5.12.3',
-    # perldata	=> '5.12.3',
-    # perlfunc	=> '5.12.3',
-    # perlstyle => '5.12.3',
-    # perlsyn	=> '5.12.3',
+    perlintro   => '5.12.3',
+    # perl       => '5.12.3',
+    # perlbook   => '5.12.3',
+    # perlcheat  => '5.12.3',
+    # perldata   => '5.12.3',
+    # perlfunc   => '5.12.3',
+    # perlstyle  => '5.12.3',
+    # perlsyn    => '5.12.3',
 };
 
-sub new {
-    return __PACKAGE__;
-}
-
-sub pod_dirs {
-    ( my $mod = __PACKAGE__ . '.pm' ) =~ s|::|/|g;
-    ( my $dir = $INC{$mod} ) =~ s/\.pm\z//;
-    return $dir;
-}
-
-sub print_pods {
-    print_pod(sort keys %$pods);
-}
 
 sub print_pod {
     my @args = @_ ? @_ : @ARGV;
 
     while (@args) {
-	(my $pod = lc(shift @args)) =~ s/\.pod$//;
-	if ( exists $pods->{$pod} ) {
-	    print "\t'$pod' traducido correspondiente a Perl
-$pods->{$pod}\n";
-	}
-	else {
-	    print "\t'$pod' todava no existe\n";
-	}
+        (my $pod = lc(shift @args)) =~ s/\.pod$//;
+        if ( exists $pods->{$pod} ) {
+            print "\t'$pod' traducido correspondiente a Perl $pods->{$pod}\n";
+        } else {
+            print "\t'$pod' no existe\n";
+        }
     }
 }
 
+
 sub search_perlfunc_re {
-    return 'Listado alfabtico de funciones de Perl';
+    return 'Lista de funciones de Perl en orden alfabtico';
 }
 
 1;
@@ -59,8 +42,7 @@ __END__
 
 =head1 NOMBRE
 
-POD2::ES - Documentacin de Perl en espaol / Spanish translation of Perl
-core documentation
+POD2::ES - Documentacin de Perl en espaol
 
 =head1 SINOPSIS
 
@@ -76,10 +58,9 @@ core documentation
 =head1 DESCRIPCIN
 
 pod2es es el proyecto de traduccin al espaol de la documentacin bsica
-de Perl. Por su dimensin, es un proyecto a largo plazo. :-) 
+de Perl. Por su dimensin, es un proyecto a largo plazo.   
 
-Consulte L<http://github.com/zipf/perldoc-es> para obtener ms informacin
-sobre el proyecto. 
+Vea L<http://github.com/zipf/perldoc-es> para obtener ms informacin. 
 
 Cuando haya instalado el paquete, puede utilizar el siguiente comando para
 consultar la documentacin: 
@@ -123,7 +104,7 @@ L<Pod::Perldoc|Pod::Perldoc>
 (incluida en Perl 5.8.7 y en Perl 5.8.8). Si tiene una distribucin de Perl
 anterior
 (salvo la E<gt>= 5.8.1) y est impaciente por aplicar la revisin,
-actualice el mdulo L<Pod::Perldoc|Pod::Perldoc> a la versin 3.14. ;-) 
+actualice el mdulo L<Pod::Perldoc|Pod::Perldoc> a la versin 3.14.   
 
 Consulte la API C<search_perlfunc_re> para obtener ms informacin.
 
@@ -161,10 +142,10 @@ pods pasados como argumentos.
 =item * C<search_perlfunc_re>
 
 Como el mtodo C<search_perlfunc> de F<Pod/Perldoc.pm> utiliza la cadena
-"Lista alfabtica de funciones de Perl" incluida en el cdigo (como una
-expresin regular) para omitir la introduccin, a fin de que el archivo de
-revisin funcione con otros idiomas con la opcin C<-L>, hemos utilizado un
-mecanismo sencillo, similar a un complemento. 
+"Lista de funciones de Perl en orden alfabtico" incluida en el cdigo
+(como una expresin regular) para omitir la introduccin, a fin de que el
+archivo de revisin funcione con otros idiomas con la opcin C<-L>, hemos
+utilizado un mecanismo sencillo, similar a un complemento. 
 
 El paquete de idioma C<POD2::E<lt>idiomaE<gt>> debe exportar
 C<search_perlfunc_re> para devolver una traduccin de la cadena mencionada
@@ -177,14 +158,15 @@ aplicar cada vez la revisin de F<Pod/Perldoc.pm>.
 
 =back
 
-=head1 Ms informacin sobre el proyecto
+=head1 PROYECTO
 
-Visite L<http://github.com/zipf/perldoc-es> para obtener ms informacin.
+Encontrar ms informacin sobre el proyecto en
+L<http://github.com/zipf/perldoc-es>.
 
 =head1 AUTORES
 
-Joaqun Ferrero C<< explorer at joaquinferrero.com >>
-y Enrique Nell C<< blas.gordon at gmail.com >>.
+=item * Joaqun Ferrero  C< explorer at joaquinferrero.com >
+=item * Enrique Nell  C< blas.gordon at gmail.com E<gt >
 
 
 =head1 VEA TAMBIN
@@ -195,9 +177,9 @@ L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>, L<perl>.
 =head1 ERRORES
 
 Puede notificar errores (bugs) o solicitar funcionalidad a travs de la
-direccin C<bug-pod2-esd at rt.cpan.org> o de la interfaz web en
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-ES>.  Se le
-comunicarn automticamente los cambios relacionados con los errores
+direccin de correo electrnico C<bug-pod2-esd at rt.cpan.org> o de la
+interfaz web en L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD2-ES>. 
+Se le comunicarn automticamente los cambios relacionados con los errores
 notificados o la funcionalidad solicitada.
 
 
@@ -242,14 +224,7 @@ Este programa es software libre; puede redistribuirlo o modificarlo bajo
 los trminos de la licencia GNU General Public License publicada por la
 Free Software Foundation, o los de la licencia Artistic.
 
-	Consulte http://dev.perl.org/licenses/ para obtener ms
-informacin.
+Consulte http://dev.perl.org/licenses/ para obtener ms informacin.
 
 
 =cut
-
-
-=head1 TRADUCTORES
-
-Joaqun Ferrero C<< explorer at joaquinferrero.com >>
-Enrique Nell C<< blas.gordon at gmail.com >>
